/**
 * Copyright 1998-2007, CHISEL Group, University of Victoria, Victoria, BC, Canada.
 * All rights reserved.
 */
package ca.uvic.csr.shrimp.jambalaya;

import ca.uvic.csr.shrimp.AttributeConstants;
import ca.uvic.csr.shrimp.VisVarConstants;
import ca.uvic.csr.shrimp.AttrToVisVarBean.AttrToVisVarBean;
import ca.uvic.csr.shrimp.jambalaya.ProtegeDataBean.ProtegeOWLDataBean;
import edu.stanford.smi.protege.model.Project;
import edu.stanford.smi.protegex.owl.model.OWLModel;
import edu.stanford.smi.protegex.owl.ui.icons.OWLIcons;

/**
 * The pupose of this class is to collect a few methods that require the Protege-OWL plugin to be installed.
 * Calling any method in this class will result in an exception if the Protege-OWL plugin is not installed
 * so just wrap your code with a try catch when calling any of the methods in this class.
 * 
 * @author Rob Lintern
 */
public class OWLSpecificUtils {
    /**
     * Determines if the given Protege project is an "OWL" project.
     * @param project
     * @return True if the knowledgebase of the given project is an "OWL" knowledgebase.
     */
    public static boolean isOwlProject(Project project) {
        return (project.getKnowledgeBase() instanceof OWLModel); 
    }
    
    /**
     * Creates the visvar attributes for the OWL Icons.
     * NoClassDefFoundError will occur if OWL isn't installed. 
     * @param attrToVisVarBean
     */
    public static void setOWLIcons(AttrToVisVarBean attrToVisVarBean) {
        attrToVisVarBean.setDefaultNominalVisualVariableValue(AttributeConstants.NOM_ATTR_ARTIFACT_TYPE, VisVarConstants.VIS_VAR_NODE_ICON, ProtegeOWLDataBean.PRIMITIVE_CLASS_TYPE, OWLIcons.getImageIcon(OWLIcons.PRIMITIVE_OWL_CLASS));      
        attrToVisVarBean.setDefaultNominalVisualVariableValue(AttributeConstants.NOM_ATTR_ARTIFACT_TYPE, VisVarConstants.VIS_VAR_NODE_ICON, ProtegeOWLDataBean.DEFINED_CLASS_TYPE, OWLIcons.getImageIcon(OWLIcons.DEFINED_OWL_CLASS));
        attrToVisVarBean.setDefaultNominalVisualVariableValue(AttributeConstants.NOM_ATTR_ARTIFACT_TYPE, VisVarConstants.VIS_VAR_NODE_ICON, ProtegeOWLDataBean.INDIVIDUAL_TYPE, OWLIcons.getImageIcon(OWLIcons.RDF_INDIVIDUAL));
        attrToVisVarBean.setDefaultNominalVisualVariableValue(AttributeConstants.NOM_ATTR_ARTIFACT_TYPE, VisVarConstants.VIS_VAR_NODE_ICON, ProtegeOWLDataBean.LOGICAL_OPERATION_TYPE, OWLIcons.getImageIcon(OWLIcons.OWL_UNION_CLASS));
        attrToVisVarBean.setDefaultNominalVisualVariableValue(AttributeConstants.NOM_ATTR_ARTIFACT_TYPE, VisVarConstants.VIS_VAR_NODE_ICON, ProtegeOWLDataBean.RESTRICTION_TYPE, OWLIcons.getImageIcon(OWLIcons.OWL_RESTRICTION));
        attrToVisVarBean.setDefaultNominalVisualVariableValue(AttributeConstants.NOM_ATTR_ARTIFACT_TYPE, VisVarConstants.VIS_VAR_NODE_ICON, ProtegeOWLDataBean.ENUMERATION_CLASS_TYPE, OWLIcons.getImageIcon("OWLEnumeratedClass"));
        attrToVisVarBean.setDefaultNominalVisualVariableValue(AttributeConstants.NOM_ATTR_ARTIFACT_TYPE, VisVarConstants.VIS_VAR_NODE_ICON, ProtegeOWLDataBean.RDFS_CLASS_TYPE, OWLIcons.getImageIcon(OWLIcons.RDFS_NAMED_CLASS));
    }

}
